@@ -21,17 +21,14 @@ import sys
 import unittest
 
 import ZConfig
-
+import ZConfig.components.logger.tests.support
+import ZConfig.tests.support
+from ZConfig._compat import NStringIO as StringIO
+from ZConfig._compat import maxsize
 from ZConfig.components.logger import datatypes
 from ZConfig.components.logger import handlers
 from ZConfig.components.logger import loghandler
 
-from ZConfig._compat import NStringIO as StringIO
-from ZConfig._compat import maxsize
-
-import ZConfig.tests.support
-import ZConfig.components.logger.tests.support
-
 
 class CustomFormatter(logging.Formatter):
     def formatException(self, ei):
@@ -342,7 +339,6 @@ class TestConfig(ZConfig.components.logger.tests.support.LoggingTestHelper,
         self.assertTrue(sio.getvalue().find("Don't panic") >= 0)
 
     def test_with_syslog(self):
-        import socket
         logger = self.check_simple_logger("<eventlog>\n"
                                           "  <syslog>\n"
                                           "    level error\n"
@@ -353,10 +349,6 @@ class TestConfig(ZConfig.components.logger.tests.support.LoggingTestHelper,
         self.assertEqual(syslog.level, logging.ERROR)
         self.assertTrue(isinstance(syslog, loghandler.SysLogHandler))
         syslog.close()  # avoid ResourceWarning
-        try:
-            syslog.socket.close()  # ResourceWarning under 3.2
-        except socket.SocketError:  # pragma: no cover
-            pass
 
     def test_with_http_logger_localhost(self):
         logger = self.check_simple_logger("<eventlog>\n"
